@@ -81,13 +81,12 @@ class EB_LAPACK(ConfigureMake):
 
     @staticmethod
     def extra_options():
-        extra_vars = [
-                      ('supply_blas', [False, "Supply BLAS lib to LAPACK for building (default: False)", CUSTOM]),
-                      ('test_only', [False, "Only make tests, don't try and build LAPACK lib.", CUSTOM])
-                     ]
+        extra_vars = {
+            'supply_blas': [False, "Supply BLAS lib to LAPACK for building", CUSTOM],
+            'test_only': [False, "Only make tests, don't try and build LAPACK lib", CUSTOM],
+        }
         return ConfigureMake.extra_options(extra_vars)
 
-
     def configure_step(self):
         """
         Configure LAPACK for build: copy build_step.inc and set make options
